==> react-nlp-annotate-0.1.17.tgz: package/components/LabelButton/index.js <==
import React from "react";
import FolderOpenIcon from "@material-ui/icons/FolderOpen";
import classnames from "classnames";
import makeStyles from "@material-ui/styles/makeStyles";
var useStyles = makeStyles({
  label: {
    display: "inline-flex",
    cursor: "pointer",
    padding: 8,
    paddingLeft: 12,
    paddingRight: 12,
    margin: 4,
    borderRadius: 4,
    fontSize: 18,
    color: "#fff",
    alignItems: "center",
    "&:hover": {
      opacity: 0.6
    },
    "&.small": {
      fontSize: 12,
      fontWeight: "bold"
    }
  }
});

var Label = function Label(props) {
  var parent = props.parent,
      color = props.color,
      displayName = props.displayName,
      description = props.description,
      id = props.id,
      small = props.small,
      hasChildren = props.hasChildren,
      hotkey = props.hotkey,
      deletable = props.deletable;
  var classes = useStyles();
  return React.createElement("div", {
    onClick: function onClick() {
      return props.onClick(id);
    },
    className: classnames(classes.label, small && "small"),
    style: {
      backgroundColor: color
    }
  }, hasChildren && React.createElement(FolderOpenIcon, {
    style: {
      width: small ? 12 : 20,
      height: small ? 12 : 20,
      marginRight: small ? 3 : 6
    }
  }), React.createElement("div", null, displayName || id), hotkey && React.createElement("div", {
    style: {
      paddingLeft: 4
    }
  }, "(", hotkey, ")"), deletable && React.createElement("div", {
    style: {
      display: "inline-flex",
      cursor: "pointer",
      alignSelf: "center",
      fontSize: 11,
      width: 18,
      height: 18,
      alignItems: "center",
      justifyContent: "center",
      marginLeft: 4,
      borderRadius: 9,
      color: "#fff",
      backgroundColor: "rgba(0,0,0,0.2)"
    }
  }, React.createElement("span", null, "\u2716")));
};

export default Label;

==> react-nlp-annotate-0.1.22.tgz: package/components/LabelButton/index.js <==
import React from "react";
import FolderOpenIcon from "@material-ui/icons/FolderOpen";
import classnames from "classnames";
import makeStyles from "@material-ui/styles/makeStyles";
var useStyles = makeStyles({
  label: {
    display: "inline-flex",
    cursor: "pointer",
    padding: 8,
    paddingLeft: 12,
    paddingRight: 12,
    margin: 4,
    borderRadius: 4,
    fontSize: 18,
    color: "#fff",
    alignItems: "center",
    "&:hover": {
      opacity: 0.6
    },
    "&.small": {
      fontSize: 12,
      fontWeight: "bold"
    }
  }
});

var Label = function Label(props) {
  var parent = props.parent,
      color = props.color,
      displayName = props.displayName,
      description = props.description,
      id = props.id,
      small = props.small,
      hasChildren = props.hasChildren,
      hotkey = props.hotkey,
      deletable = props.deletable;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement("div", {
    onClick: function onClick() {
      return props.onClick(id);
    },
    className: classnames(classes.label, small && "small"),
    style: {
      backgroundColor: color
    }
  }, hasChildren && /*#__PURE__*/React.createElement(FolderOpenIcon, {
    style: {
      width: small ? 12 : 20,
      height: small ? 12 : 20,
      marginRight: small ? 3 : 6
    }
  }), /*#__PURE__*/React.createElement("div", null, displayName || id), hotkey && /*#__PURE__*/React.createElement("div", {
    style: {
      paddingLeft: 4
    }
  }, "(", hotkey, ")"), deletable && /*#__PURE__*/React.createElement("div", {
    style: {
      display: "inline-flex",
      cursor: "pointer",
      alignSelf: "center",
      fontSize: 11,
      width: 18,
      height: 18,
      alignItems: "center",
      justifyContent: "center",
      marginLeft: 4,
      borderRadius: 9,
      color: "#fff",
      backgroundColor: "rgba(0,0,0,0.2)"
    }
  }, /*#__PURE__*/React.createElement("span", null, "\u2716")));
};

export default Label;
